@@ -165,10 +165,19 @@ plot.phreg <- function(x,
                                       param = "canonical") ##* score
             }
         }else if (x$param == "rate"){
+            ##scale <- log(scale) # Added 15 Jul 2018. Removed 19 Jul 2018!
+            ##scale <- 1 / scale
+            scale <- log(scale)
+            ##if (printlevel){
+              ##  cat("scale = ", scale, "\n")
+                ##cat("shape = ", shape, "\n")
+            ##}
             for (i in 1:ns){
-                haz[i, ] <- exp(shape + xx * scale) * score
-                Haz[i, ] <- exp(shape) * score * expm1(xx * scale) / scale
-                sur[i, ] <- exp(-Haz[, i])
+                ##haz[i, ] <- hgompertz(xx, shape = score * shape[i], scale = scale[i])
+                haz[i, ] <- shape[i] * exp(xx * scale[i]) * score
+                ##Haz[i, ] <- Hgompertz(xx, shape = score * shape[i], scale = scale[i])
+                Haz[i, ] <- shape[i] * score * expm1(xx * scale[i]) / scale[i]
+                sur[i, ] <- exp(-Haz[i, ]) # Fixed 15 Jul 2018 (order [i, ])
             }
         }
 
